ExprIdentifier

Struct ExprIdentifier 

pub struct ExprIdentifier(pub String, pub IdentifierKind, pub Option<Type>);

Tuple Fields

0: String1: IdentifierKind2: Option<Type>

Implementations

Source

impl ExprIdentifier

pub fn new(identifier: &str) -> Self

pub fn get_identifier_kind(identifier: &str) -> IdentifierKind

pub fn full_name(&self) -> &str

The full name of the identifier from the source code

This is different from [Self::name] as it always includes a sigil prefix for variables, prompts, secrets, and client identifiers.

pub fn lookup_name(&self) -> &str

The look up name for the identifier

For builtins this is just the identifier name

For variables, prompts, secrets, and client identifiers, it returns the non sigil prefix version of the identifier.

  • builtin_fn => builtin_fn
  • :variable => variable
  • ?prompt => prompt
  • !secret => secret
  • @client => client
pub fn identifier_kind(&self) -> &IdentifierKind

pub fn get_type(&self) -> &Option<Type>